##  Cost Reports
Cost reports are a powerful tool that helps organizations to understand the cost of their IT landscape. The SAP LeanIX Cost Reports provide an overview of which business capabilities are supported by which applications, which projects are running, which providers are being used, and how much they cost annually.
By using the Cost Reports, you can analyze the cost allocation per business capability, application, and provider, and identify areas where costs can be reduced. For example, if you find that a particular application is supporting multiple business capabilities, you can analyze the cost of each business capability and identify areas where costs can be optimized. Learn more about [Cost Management here](https://help.sap.com/docs/leanix/ea/cost-management?locale=en-US&state=PRODUCTION&version=CLOUD "Track and analyze IT costs across projects, applications, and infrastructure. Support strategic financial decisions in enterprise architecture with the right insights from reports.").
SAP LeanIX provides two default Cost reports:
  1. The Business Capability Cost Report gives you an overview of which business capabilities are supported by which applications and how much this support costs annually. This report helps you understand the cost allocation per business capability and analyze where costs could be reduced.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274cc5be7a4410148f62e61c520beed0_LowRes.png)


To discover which Applications are causing expenses for a particular Business Capability, you can click on the relevant bar graph to obtain additional information. You can also access the corresponding Application Fact Sheets by clicking on the left-hand link within the window that appears.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2756faa67a4410148aad8b2c3c1c35c9_LowRes.gif)
**Note**
In order for the Business Capability Cost report to work, you need to set the attribute "Support Type" on the Application - Business Capability relation to "Leading". This way, SAP LeanIX makes sure that run costs are only counted for one Business Capability.
In the rare case where an Application is set to "Leading" for multiple Business Capabilities, run costs will be split equally between these Business Capabilities.
  1. The Provider Cost Report shows you the cost allocation per provider either as a pie chart or in a table view. This report helps you understand how much you are spending on each provider and identify areas where you could negotiate better rates.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274526967a441014befdfe56cabcdd2a_LowRes.png)


You can navigate to the respective Provider Fact Sheet by simply clicking on the graph.
